@@ -27,14 +27,15 @@ autoplot.MAPshp <- function(object,
                             map_title = NULL,
                             facet = FALSE,
                             printed = TRUE){
-
+  lifecycle::deprecate_stop("1.5.0", "autoplot.MAPshp", details = "This function will is deprecated. getShp should return an object of type sf.")
+  
   if(is.null(map_title)){
     map_title <- paste0(paste0(unique(object$name_0), collapse = ", "),": ",paste0("admin", unique(object$admn_level), collapse = ", "))
   }
 
-  plot <- ggplot2::ggplot()+
-    ggplot2::geom_polygon(data = object, aes_string(x="long", y = "lat", group = "group"), colour = "grey50", fill = "grey95")+
-    ggplot2::coord_equal()+
+  plot <- ggplot2::ggplot(object) +
+    ggplot2::geom_sf(aes(group = "group"), colour = "grey50", fill = "grey95") +
+    ggplot2::coord_sf() +
     ggplot2::theme(plot.title = ggplot2::element_text(vjust=-1),
                    strip.text = ggplot2::element_text(face = "bold"),
                    strip.background = element_blank(),
@@ -44,7 +45,6 @@ autoplot.MAPshp <- function(object,
                    panel.border = ggplot2::element_rect(colour = "grey50", fill=NA, size = 0.5))+
     ggtitle(paste(map_title))
 
-
   if(all(c(0,1) %in% unique(object$admn_level))){
     if(facet == TRUE){
      plot <- plot + ggplot2::facet_wrap(~country_level)
@@ -52,7 +52,7 @@ autoplot.MAPshp <- function(object,
   }
 
   if(printed ==TRUE){
-  print(plot)
+    print(plot)
   }
 
   return(invisible(plot))
