@@ -10,7 +10,7 @@
 #' @param ISO string containing ISO3 code for desired country, e.g. \code{c("XXX", "YYY", ...)} OR \code{ = "ALL"}. (Use one of \code{country} OR \code{ISO} OR \code{continent}, not combined)
 #' @param continent string containing continent (one of "Africa", "Americas", "Asia", "Oceania") for desired data, e.g. \code{c("continent1", "continent2", ...)}. (Use one of \code{country} OR \code{ISO} OR \code{continent}, not combined)
 #' @param species string specifying the Plasmodium species for which to find PR points, options include: \code{"Pf"} OR \code{"Pv"} OR \code{"BOTH"}
-#' @param extent 2x2 matrix specifying the spatial extent within which PR data is desired, as returned by sp::bbox() - the first column has the minimum, the second the maximum values; rows 1 & 2 represent the x & y dimensions respectively (matrix(c("xmin", "ymin","xmax", "ymax"), nrow = 2, ncol = 2, dimnames = list(c("x", "y"), c("min", "max"))))
+#' @param extent an object specifying spatial extent within which PR data is desired, as returned by sf::st_bbox().
 #'
 #'
 #' @return \code{getPR} returns a dataframe containing the below columns, in which each row represents a distinct data point/ study site.
@@ -61,6 +61,9 @@ getPR <- function(country = NULL,
     stop("Must specify one of: 'country', 'ISO', 'continent', or 'extent'.")
   }
   
+  if (!is.null(extent)) {
+    extent <- getSpBbox(extent)
+  }
   
   URL <-
     "https://malariaatlas.org/geoserver/Explorer/ows?service=wfs&version=2.0.0&request=GetFeature&outputFormat=csv&TypeName=PR_Data"
@@ -176,13 +179,13 @@ getPR <- function(country = NULL,
       stop(
         "Error in downloading data for extent: (",
         paste0(extent, collapse = ","),
-        "),\n try query using country or continent name OR check data availability at malariaatlas.org/explorer."
+        "),\n try query using country or continent name OR check data availability at https://data.malariaatlas.org/maps."
       )
     }
     
     if (nrow(df) == 0) {
       stop(
-        "PR data points are not available for the specified species in requested countries; \n confirm species-specific data availability at malariaatlas.org/explorer."
+        "PR data points are not available for the specified species in requested countries; \n confirm species-specific data availability at https://data.malariaatlas.org/maps."
       )
     }
     
