@@ -31,27 +31,27 @@ test_that("correct error messages are returned for various combinations of count
   expect_warning(isAvailable(country = c("Brazil","Libya","Ngeria"), sourcedata = "vector points"), "Data not found for 'Ngeria', did you mean Nigeria")
   
 #one wrong
-  expect_error(isAvailable(country = "Australia", sourcedata = "pr points"), "Specified location not found, see below comments:")
-  expect_error(isAvailable(country = "Australia", sourcedata = "pr points"), "Data not found for 'Australia', use listPoints()")
-  expect_error(isAvailable(country = "Libya", sourcedata = "vector points"), "Specified location not found, see below comments:")
-  expect_error(isAvailable(country = "Libya", sourcedata = "vector points"), "Data not found for 'Libya', use listPoints()")
+  expect_message(isAvailable(country = "Australia", sourcedata = "pr points"), "Specified location not found, see below comments:")
+  expect_message(isAvailable(country = "Australia", sourcedata = "pr points"), "Data not found for 'Australia', use listPoints()")
+  expect_message(isAvailable(country = "Libya", sourcedata = "vector points"), "Specified location not found, see below comments:")
+  expect_message(isAvailable(country = "Libya", sourcedata = "vector points"), "Data not found for 'Libya', use listPoints()")
 #one mispelled
-  expect_error(isAvailable(country = "Ngeria", sourcedata = "pr points"), "Specified location not found, see below comments:")
-  expect_error(isAvailable(country = "Ngeria", sourcedata = "pr points"), "Data not found for 'Ngeria', did you mean Nigeria")
-  expect_error(isAvailable(country = "Ngeria", sourcedata = "vector points"), "Specified location not found, see below comments:")
-  expect_error(isAvailable(country = "Ngeria", sourcedata = "vector points"), "Data not found for 'Ngeria', did you mean Nigeria")
+  expect_message(isAvailable(country = "Ngeria", sourcedata = "pr points"), "Specified location not found, see below comments:")
+  expect_message(isAvailable(country = "Ngeria", sourcedata = "pr points"), "Data not found for 'Ngeria', did you mean Nigeria")
+  expect_message(isAvailable(country = "Ngeria", sourcedata = "vector points"), "Specified location not found, see below comments:")
+  expect_message(isAvailable(country = "Ngeria", sourcedata = "vector points"), "Data not found for 'Ngeria', did you mean Nigeria")
 #one wrong, one mispelled
-  expect_error(isAvailable(country = c("Australia","Ngeria"), sourcedata = "pr points"), "Specified location not found, see below comments:")
-  expect_error(isAvailable(country = c("Australia","Ngeria"), sourcedata = "pr points"), "Data not found for 'Australia', use listPoints()")
-  expect_error(isAvailable(country = c("Australia","Ngeria"), sourcedata = "pr points"), "Data not found for 'Ngeria', did you mean Nigeria")
-  expect_error(isAvailable(country = c("Libya","Ngeria"), sourcedata = "vector points"), "Specified location not found, see below comments:")
-  expect_error(isAvailable(country = c("Libya","Ngeria"), sourcedata = "vector points"), "Data not found for 'Libya', use listPoints()")
-  expect_error(isAvailable(country = c("Libya","Ngeria"), sourcedata = "vector points"), "Data not found for 'Ngeria', did you mean Nigeria")
+  expect_message(isAvailable(country = c("Australia","Ngeria"), sourcedata = "pr points"), "Specified location not found, see below comments:")
+  expect_message(isAvailable(country = c("Australia","Ngeria"), sourcedata = "pr points"), "Data not found for 'Australia', use listPoints()")
+  expect_message(isAvailable(country = c("Australia","Ngeria"), sourcedata = "pr points"), "Data not found for 'Ngeria', did you mean Nigeria")
+  expect_message(isAvailable(country = c("Libya","Ngeria"), sourcedata = "vector points"), "Specified location not found, see below comments:")
+  expect_message(isAvailable(country = c("Libya","Ngeria"), sourcedata = "vector points"), "Data not found for 'Libya', use listPoints()")
+  expect_message(isAvailable(country = c("Libya","Ngeria"), sourcedata = "vector points"), "Data not found for 'Ngeria', did you mean Nigeria")
 #nonsense
-  expect_error(isAvailable(country = "XfUEC43", sourcedata = "pr points"), "Specified location not found, see below comments:")
-  expect_error(isAvailable(country = "XfUEC43", sourcedata = "pr points"), "Data not found for 'Xfuec43', use listPoints()")
-  expect_error(isAvailable(country = "XfUEC43", sourcedata = "vector points"), "Specified location not found, see below comments:")
-  expect_error(isAvailable(country = "XfUEC43", sourcedata = "vector points"), "Data not found for 'Xfuec43', use listPoints()")
+  expect_message(isAvailable(country = "XfUEC43", sourcedata = "pr points"), "Specified location not found, see below comments:")
+  expect_message(isAvailable(country = "XfUEC43", sourcedata = "pr points"), "Data not found for 'Xfuec43', use listPoints()")
+  expect_message(isAvailable(country = "XfUEC43", sourcedata = "vector points"), "Specified location not found, see below comments:")
+  expect_message(isAvailable(country = "XfUEC43", sourcedata = "vector points"), "Data not found for 'Xfuec43', use listPoints()")
   
   })
 
